@@ -67,21 +67,23 @@ get '/' => sub ($c) {
 
 get '/model' => sub ($c) {
   my $model  = $c->param('model');
+  my $specs  = $c->param('specs');
   my $groups = $c->param('groups');
   my $group_list = $groups ? [ split /\s*,\s*/, $groups ] : undef;
   $c->render(
     template   => 'model',
     model      => $model,
+    specs      => $specs,
     groups     => $groups,
     group_list => $group_list,
   );
 } => 'model';
-post '/new_model' => sub ($c) {
+post '/model' => sub ($c) {
   my $v = $c->validation;
   $v->required('model');
   $v->required('groups');
   if ($v->failed->@*) {
-    $c->flash(error => 'Could not add model');
+    $c->flash(error => 'Could not update model');
     return $c->redirect_to('model');
   }
   my $synth = Synth::Config->new(model => $v->param('model'));
@@ -96,7 +98,7 @@ post '/new_model' => sub ($c) {
       $i++;
     }
     store($specs, $model_file);
-    $c->flash(message => 'Add parameters successful');
+    $c->flash(message => 'Update parameters successful');
     return $c->redirect_to($c->url_for('index')->query(model => $v->param('model')));
   }
   else {
@@ -107,13 +109,32 @@ post '/new_model' => sub ($c) {
       return $c->redirect_to('model');
     }
     $specs->{group} = [ split /\s*,\s*/, $v->param('groups') ];
-    $specs->{parameter}{$_} = [] for $specs->{group}->@*; # TODO handle population
+    $specs->{parameter}{$_} = [] for $specs->{group}->@*;
     my $model_file = SETTINGS . $synth->model . '.dat';
     store($specs, $model_file);
     $c->flash(message => 'Add model successful');
     return $c->redirect_to($c->url_for('model')->query(model => $v->param('model'), groups => $v->param('groups')));
   }
-} => 'new_model';
+} => 'update_model';
+get '/edit_model' => sub ($c) {
+  my $v = $c->validation;
+  $v->required('model');
+  if ($v->failed->@*) {
+    $c->flash(error => 'Could not edit model');
+    return $c->redirect_to($c->url_for('index')->query(model => $v->param('model')));
+  }
+  my $synth = Synth::Config->new(model => $v->param('model'));
+  my $model_file = SETTINGS . $synth->model . '.dat';
+  my $specs = -e $model_file ? retrieve($model_file) : undef;
+  my $groups = join ',', $specs->{group}->@*;
+  $c->render(
+    template   => 'edit_model',
+    model      => $v->param('model'),
+    groups     => $groups,
+    group_list => $specs->{group},
+    specs      => $specs->{parameter},
+  );
+} => 'edit_model';
 
 get '/remove' => sub ($c) {
   my $v = $c->validation;
@@ -255,7 +276,6 @@ __DATA__
 
 @@ index.html.ep
 % layout 'default';
-% title 'Synth::Config';
 <p></p>
 <form action="<%= url_for('index') %>" method="get">
 <div class="row">
@@ -287,7 +307,7 @@ __DATA__
 <p></p>
 <div class="row">
   <div class="col">
-    <input type="text" name="fields" id="fields" value="<%= $fields %>" class="form-control" placeholder="field1:value1, field2:value2, etc.">
+    <input type="text" name="fields" id="fields" value="<%= $fields %>" class="form-control" placeholder="Search field1:value1, field2:value2, etc.">
   </div>
 </div>
 <p></p>
@@ -299,6 +319,7 @@ __DATA__
 % }
     <a href="<%= url_for('model') %>" class="btn btn-success"><i class="fa-solid fa-database"></i> New model</a>
 % if ($model) {
+    <a href="<%= url_for('edit_model')->query(model => $model) %>" class="btn btn-success"><i class="fa-solid fa-pencil"></i> Edit model</a>
     <a href="<%= url_for('remove')->query(model => $model) %>" class="btn btn-danger" onclick="if(!confirm('Remove model?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove model</a>
 % }
   </div>
@@ -341,9 +362,8 @@ __DATA__
 
 @@ model.html.ep
 % layout 'default';
-% title 'Synth::Config';
 <p></p>
-<form action="<%= url_for('new_model') %>" method="post">
+<form action="<%= url_for('update_model') %>" method="post">
 <div class="row">
   <div class="col">
     <input type="text" name="model" id="model" value="<%= $model %>" class="form-control" placeholder="Model name" required>
@@ -359,7 +379,7 @@ __DATA__
 <div class="row">
   <div class="col">
 % unless ($group_list) {
-    <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Add Model</button>
+    <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Add model</button>
 % }
     <a href="<%= url_for('index') %>" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
   </div>
@@ -367,7 +387,7 @@ __DATA__
 </form>
 % if ($group_list) {
 <p></p>
-<form action="<%= url_for('new_model') %>" method="post">
+<form action="<%= url_for('update_model') %>" method="post">
   <input type="hidden" name="model" value="<%= $model %>">
   <input type="hidden" name="groups" value="<%= $groups %>">
 %   for my $g (@$group_list) {
@@ -379,9 +399,42 @@ __DATA__
 % }
 
 
+@@ edit_model.html.ep
+% layout 'default';
+<p></p>
+<div class="row">
+  <div class="col">
+    <label for="model">Model:</label>
+    <input type="text" name="model" id="model" value="<%= $model %>" class="form-control" disabled readonly>
+  </div>
+</div>
+<p></p>
+<div class="row">
+  <div class="col">
+    <label for="group">Group:</label>
+    <input type="text" id="group" value="<%= $groups %>" class="form-control" disabled readonly>
+  </div>
+</div>
+<p></p>
+<form action="<%= url_for('update_model') %>" method="post">
+  <input type="hidden" name="model" value="<%= $model %>">
+  <input type="hidden" name="groups" value="<%= $groups %>">
+% for my $g (@$group_list) {
+  <label for="<%= $g %>_param"><%= ucfirst $g %>:</label>
+  <input type="text" name="group" id="<%= $g %>_param" value="<%= join ',', $specs->{$g}->@* %>" class="form-control" placeholder="<%= ucfirst $g %> parameter1, param2, etc.">
+  <p></p>
+% }
+  <div class="row">
+    <div class="col">
+      <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Update model</button>
+      <a href="<%= url_for('index')->query(model => $model) %>" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
+    </div>
+  </div>
+</form>
+
+
 @@ edit.html.ep
 % layout 'default';
-% title 'Synth::Config';
 <p></p>
 <form action="<%= url_for('update') %>" method="post">
   <input type="hidden" name="id" value="<%= $id %>">
@@ -539,6 +592,7 @@ $(document).ready(function() {
 
 
 @@ layouts/default.html.ep
+% title 'Synth::Config';
 <!DOCTYPE html>
 <html lang="en">
   <head>
@@ -577,3 +631,4 @@ $(document).ready(function() {
     </div>
   </body>
 </html>
+
