@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0027';
+our $VERSION = '0.0028';
 
 use Moo;
 use strictures 2;
@@ -221,7 +221,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0027
+version 0.0028
 
 =head1 SYNOPSIS
 
@@ -233,17 +233,17 @@ version 0.0027
 
   my $name = 'Foo!';
 
-  my $id1 = $synth->make_setting(name => $name, etc => '...');
-  my $id2 = $synth->make_setting(name => $name, etc => '???');
+  my $id1 = $synth->make_setting(name => $name, group => '...');
+  my $id2 = $synth->make_setting(name => $name, group => '???');
 
   my $setting = $synth->recall_setting(id => $id1);
-  # { etc => '...' }
+  # { group => '...' }
 
-  # update the etc key only
-  $synth->make_setting(id => $id1, etc => '!!!');
+  # update the group key only
+  $synth->make_setting(id => $id1, group => '!!!');
 
-  my $settings = $synth->search_settings(etc => '???');
-  # [ 2 => { etc => '???' } ]
+  my $settings = $synth->search_settings(group => '???');
+  # [ 2 => { group => '???' } ]
 
   my $models = $synth->recall_models;
   # [ 'moog_matriarch' ]
